@@ -35,8 +35,8 @@ async def send(
     recipients: Optional[Union[str, Sequence[str]]] = ...,
     hostname: str = ...,
     port: Optional[int] = ...,
-    username: Optional[str] = ...,
-    password: Optional[str] = ...,
+    username: Optional[Union[str, bytes]] = ...,
+    password: Optional[Union[str, bytes]] = ...,
     mail_options: Optional[List[str]] = ...,
     rcpt_options: Optional[List[str]] = ...,
     timeout: Optional[float] = ...,
@@ -61,8 +61,8 @@ async def send(
     recipients: Union[str, Sequence[str]] = ...,
     hostname: str = ...,
     port: Optional[int] = ...,
-    username: Optional[str] = ...,
-    password: Optional[str] = ...,
+    username: Optional[Union[str, bytes]] = ...,
+    password: Optional[Union[str, bytes]] = ...,
     mail_options: Optional[List[str]] = ...,
     rcpt_options: Optional[List[str]] = ...,
     timeout: Optional[float] = ...,
@@ -87,8 +87,8 @@ async def send(
     recipients: Optional[Union[str, Sequence[str]]] = ...,
     hostname: str = ...,
     port: Optional[int] = ...,
-    username: Optional[str] = ...,
-    password: Optional[str] = ...,
+    username: Optional[Union[str, bytes]] = ...,
+    password: Optional[Union[str, bytes]] = ...,
     mail_options: Optional[List[str]] = ...,
     rcpt_options: Optional[List[str]] = ...,
     timeout: Optional[float] = ...,
@@ -113,8 +113,8 @@ async def send(
     recipients: Union[str, Sequence[str]] = ...,
     hostname: str = ...,
     port: Optional[int] = ...,
-    username: Optional[str] = ...,
-    password: Optional[str] = ...,
+    username: Optional[Union[str, bytes]] = ...,
+    password: Optional[Union[str, bytes]] = ...,
     mail_options: Optional[List[str]] = ...,
     rcpt_options: Optional[List[str]] = ...,
     timeout: Optional[float] = ...,
@@ -139,8 +139,8 @@ async def send(
     recipients: Optional[Union[str, Sequence[str]]] = ...,
     hostname: None = ...,
     port: None = ...,
-    username: Optional[str] = ...,
-    password: Optional[str] = ...,
+    username: Optional[Union[str, bytes]] = ...,
+    password: Optional[Union[str, bytes]] = ...,
     mail_options: Optional[List[str]] = ...,
     rcpt_options: Optional[List[str]] = ...,
     timeout: Optional[float] = ...,
@@ -165,8 +165,8 @@ async def send(
     recipients: Union[str, Sequence[str]] = ...,
     hostname: None = ...,
     port: None = ...,
-    username: Optional[str] = ...,
-    password: Optional[str] = ...,
+    username: Optional[Union[str, bytes]] = ...,
+    password: Optional[Union[str, bytes]] = ...,
     mail_options: Optional[List[str]] = ...,
     rcpt_options: Optional[List[str]] = ...,
     timeout: Optional[float] = ...,
@@ -191,8 +191,8 @@ async def send(
     recipients: Optional[Union[str, Sequence[str]]] = ...,
     hostname: None = ...,
     port: None = ...,
-    username: Optional[str] = ...,
-    password: Optional[str] = ...,
+    username: Optional[Union[str, bytes]] = ...,
+    password: Optional[Union[str, bytes]] = ...,
     mail_options: Optional[List[str]] = ...,
     rcpt_options: Optional[List[str]] = ...,
     timeout: Optional[float] = ...,
@@ -217,8 +217,8 @@ async def send(
     recipients: Union[str, Sequence[str]] = ...,
     hostname: None = ...,
     port: None = ...,
-    username: Optional[str] = ...,
-    password: Optional[str] = ...,
+    username: Optional[Union[str, bytes]] = ...,
+    password: Optional[Union[str, bytes]] = ...,
     mail_options: Optional[List[str]] = ...,
     rcpt_options: Optional[List[str]] = ...,
     timeout: Optional[float] = ...,
@@ -243,8 +243,8 @@ async def send(
     recipients: Optional[Union[str, Sequence[str]]] = ...,
     hostname: None = ...,
     port: None = ...,
-    username: Optional[str] = ...,
-    password: Optional[str] = ...,
+    username: Optional[Union[str, bytes]] = ...,
+    password: Optional[Union[str, bytes]] = ...,
     mail_options: Optional[List[str]] = ...,
     rcpt_options: Optional[List[str]] = ...,
     timeout: Optional[float] = ...,
@@ -269,8 +269,8 @@ async def send(
     recipients: Union[str, Sequence[str]] = ...,
     hostname: None = ...,
     port: None = ...,
-    username: Optional[str] = ...,
-    password: Optional[str] = ...,
+    username: Optional[Union[str, bytes]] = ...,
+    password: Optional[Union[str, bytes]] = ...,
     mail_options: Optional[List[str]] = ...,
     rcpt_options: Optional[List[str]] = ...,
     timeout: Optional[float] = ...,
@@ -295,8 +295,8 @@ async def send(
     recipients: Optional[Union[str, Sequence[str]]] = ...,
     hostname: None = ...,
     port: None = ...,
-    username: Optional[str] = ...,
-    password: Optional[str] = ...,
+    username: Optional[Union[str, bytes]] = ...,
+    password: Optional[Union[str, bytes]] = ...,
     mail_options: Optional[List[str]] = ...,
     rcpt_options: Optional[List[str]] = ...,
     timeout: Optional[float] = ...,
@@ -321,8 +321,8 @@ async def send(
     recipients: Union[str, Sequence[str]] = ...,
     hostname: None = ...,
     port: None = ...,
-    username: Optional[str] = ...,
-    password: Optional[str] = ...,
+    username: Optional[Union[str, bytes]] = ...,
+    password: Optional[Union[str, bytes]] = ...,
     mail_options: Optional[List[str]] = ...,
     rcpt_options: Optional[List[str]] = ...,
     timeout: Optional[float] = ...,
